rm(list=ls())

##Set working directory manually or with the following command##
#getwd()
#setwd("insert_your_pathway")

## read the data from file and attach it
count_data <- read.table("sinclair.txt", header=T)
attach(count_data)

### PART I. 2-Way Contingency Tables ###

## use the xtabs() function to create 2-way contingency tables
marrow_death_xtab <- xtabs(count ~ death + marrow)
sex_death_xtab <- xtabs(count ~ death + sex)
marrow_sex_xtab <- xtabs(count ~ sex + marrow)

## use the mosaicplot() function to display the 2-way tables
par(mfrow=c(1,3))
mosaicplot(marrow_death_xtab, shade=T, main="Marrow vs. Death")
mosaicplot(sex_death_xtab, shade=T, main="Sex vs. Death")
mosaicplot(marrow_sex_xtab, shade=T, main="Marrow vs. Sex")
par(mfrow=c(1,1))

## perform Pearson's chi-squared test on the 2-way tables
chisq.test(marrow_death_xtab, correct=F)
chisq.test(sex_death_xtab, correct=F)
chisq.test(marrow_sex_xtab, correct=F)

### PART II. Log-Linear Models for Multi-Way Contingency Tables ###

## create an empty table to hold the results (see Slide 39 of Powerpoint)
colnames <- c("Model","G-squared","df","P-value","AIC")
rownames <- seq(1,9)
gtable <- matrix(nrow=9,ncol=5,dimnames=list(rownames, colnames))

## create hierarchical log-linear models
model1 <- glm(count ~ death + sex + marrow, family=poisson)
model2 <- glm(count ~ death + sex + marrow + death:sex, family=poisson)
model3 <- glm(count ~ death + sex + marrow + death:marrow, family=poisson)
model4 <- glm(count ~ death + sex + marrow + sex:marrow, family=poisson)
model5 <- glm(count ~ death*sex + death*marrow, family=poisson)
model6 <- glm(count ~ death*sex + sex*marrow, family=poisson)
model7 <- glm(count ~ death*marrow + sex*marrow, family=poisson)
model8 <- glm(count ~ death*sex + death*marrow + sex*marrow, family=poisson)
model9 <- glm(count ~ death*sex*marrow, family=poisson)

## combine all of the models into a list and then loop over each one
models <- list(model1,model2,model3,model4,model5,model6,model7,model8,model9)
for (i in 1:length(models)) {

	## write the formula, G-squared, df, P-value, and AIC for the model to gtable
	model <- models[[i]]
	gtable[i,1] <- toString(model$formula)
	gtable[i,2] <- model$deviance
	gtable[i,3] <- model$df.residual
	gtable[i,4] <- 1-pchisq(model$deviance, model$df.residual)
	gtable[i,5] <- model$deviance - 2*model$df.residual
}


## display the table with the model results
gtable[9,5] <- ""		## there is no AIC for the saturated model
gtable

## test for complete independence
anova(model1, model8, test="Chi")

## test for three-way interaction
anova(model8, model9, test="Chi")

## tests for conditional independence
anova(model7, model8, test="Chi")	## test death vs. sex
anova(model6, model8, test="Chi")	## test death vs. marrow
anova(model5, model8, test="Chi")	## test sex vs. marrow

## tests for marginal independence
anova(model4, model1, test="Chi")
anova(model3, model1, test="Chi")
anova(model2, model1, test="Chi")

## create a contingency table of death vs. marrow for females
female_data <- count_data[sex=="FEMALE",]
female_xtab <- xtabs(count ~ death + marrow, data=female_data)

## create a contingency table of death vs. marrow for males
male_data <- count_data[sex=="MALE",]
male_xtab <- xtabs(count ~ death + marrow, data=male_data)

## plot the contingency tables
par(mfrow=c(1,2))
mosaicplot(female_xtab, shade=T, main="Females")
mosaicplot(male_xtab, shade=T, main="Males")
par(mfrow=c(1,1))

## detach the data
detach(count_data)